# acapela_box

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

acapela_ voices online not official API

## installing
`pip install https://github.com/alekssamos/acapela_box/archive/refs/heads/master.zip`

## using
see file ./example1.py

or from command line
```bash
$ acapela_box "fr-FR" "AntoineFromAfar"     "Ce module est développé par un français."
https://vaasbox.acapela-box.com/MESSAGES/013099097112101108097066111120095086050/Listen.php?q=NiivxaaFRPDRk2FD7Lfg!CV7fN
MzZD!aYmkMKE_u1OIUZmfHJWx1IW09pewrMyoZ.mp3
```

This library is compatible with [Ge0/acapela-group](https://github.com/Ge0/acapela-group)
